::##
::## PROGRAM TO DOWNLOAD DATA FROM THE 00z-0.5-DEGREE GFS MODEL FOR MEXICO-CARIBBEAN
::##
::## This program is designed to download grib data every three hours during the first 36
::## hours and every six hours starting at F42.  It then converts the downloaded files to
::## Wingridds_V3.2 format. Note that Wingridds version 3.2 is required for the Wingridds
::## conversion to work.
::##
::## Programmed by Juan Jose Amides Figueroa  -- joseamidesfigueroa@gmail.com 
::##                                          -- juanfigueroa@marn.gob.sv
::## Revised and edited by Jose Manuel Galvez -- jose.galvez@noaa.gov
::##                                          -- jomagalvez@gmail.com
::## Revised by Angelo Pascualetti Ardiles    -- apascualetti@dgac.cl
::## 
::## Special thanks to Mike Davison for his guidance, help and support,
::## and to Jeff Krob for his support with the Wingridds software.
::## College Park, Maryland, USA, International Desk Training, July 2014.
::##
::##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
::##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
::##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
::##                           DO NOT MODIFY UNDER THIS LINE
::##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
::##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
::##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@



::######AREA TO DOWNLOAD----------------------------------------------------------------------
set toplat=37
set leftlon=-119
set bottomlat=-1
set rightlon=-42

::######WINGRIDDS FOLDERS---------------------------------------------------------------------
set folderwingriddsnws=C:\WINGRIDDS\GRIB\NWS
set folderwingriddssector=C:\WINGRIDDS\datosector_gfs\en
set folderwingridds=C:\WINGRIDDS

::######DEFINE SYSTEM DATE AND TIME-----------------------------------------------------------
set date_string=%date:~10,4%%date:~4,2%%date:~7,2%
echo Date to use: %date_string%

::######ERASE RESIDUAL DATA-------------------------------------------------------------------
C:
cd %folderwingriddsnws%
del *.* /Q
cd %folderwingriddssector%
del *gfs.* /Q

::######DATA DOWNLOAD----------------------------------------------------------
ECHO DOWNLOADING F00
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f00&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F03
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f03&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F06
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f06&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F09
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f09&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F12
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f12&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F15
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f15&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F18
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f18&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F21
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f21&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F24
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f24&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F27
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f27&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F30
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f30&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F33
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f33&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F36
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f36&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F42
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f42&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F48
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f48&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F54
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f54&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F60
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f60&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F66
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f66&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F72
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f72&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F78
START /B aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f78&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"
ECHO DOWNLOADING F84
aria2c.exe -j7 -k1M -x16 "http://nomads.ncep.noaa.gov/cgi-bin/filter_gfs_hd.pl?file=gfs.t00z.mastergrb2f84&all_lev=on&all_var=on&subregion=&leftlon=%leftlon%&rightlon=%rightlon%&toplat=%toplat%&bottomlat=%bottomlat%&dir=%%2Fgfs.%date_string%00%%2Fmaster"



::######MOVE DOWNLOADED DATA TO THE NWS FOLDER------------------------------------------------
move *gfs.* %folderwingriddsnws%

::######CONVERT ALL DATA TO THE WINGRIDDS FORMAT----------------------------------------------
cd %folderwingridds%
Ngrb2pcg32.exe